==> haskell-pango-0.13.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/gtk2hs-pango/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.1.1
id: pango-0.13.1.1-c4950bb904f1773185522420ff6e131a
key: pango_2cIL87Bh7ZeLkiM5NMiqHc
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Font
    Graphics.Rendering.Pango.Enums Graphics.Rendering.Pango.Context
    Graphics.Rendering.Pango.Layout Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Types Graphics.Rendering.Pango.BasicTypes
    Graphics.Rendering.Pango.Structs
    Graphics.Rendering.Pango.Attributes
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pango-0.13.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/pango-0.13.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/pango-0.13.1.1
hs-libraries: HSpango-0.13.1.1-2cIL87Bh7ZeLkiM5NMiqHc
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/libdrm /usr/include/glib-2.0
              /usr/lib/glib-2.0/include
includes:
    hspango.h
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    cairo-0.13.1.1-7f2d3a6c061090f92b30733949132fce
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    glib-0.13.2.2-af22ca5ff15cdc3e58e6f0b0228d4cfc
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pango-0.13.1.1-3-armv7h.pkg.tar.xz: usr/share/haskell/gtk2hs-pango/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.1.1
id: pango-0.13.1.1-d769eb4acf7fd5168f234735f2d8eddf
key: pango_KgG1Z92ZTgJEQtWynhlo9f
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Font
    Graphics.Rendering.Pango.Enums Graphics.Rendering.Pango.Context
    Graphics.Rendering.Pango.Layout Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Types Graphics.Rendering.Pango.BasicTypes
    Graphics.Rendering.Pango.Structs
    Graphics.Rendering.Pango.Attributes
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/pango-0.13.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/pango-0.13.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/pango-0.13.1.1
hs-libraries: HSpango-0.13.1.1-KgG1Z92ZTgJEQtWynhlo9f
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/libdrm /usr/include/glib-2.0
              /usr/lib/glib-2.0/include
includes:
    hspango.h
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    cairo-0.13.1.1-239a9d133d75921503420754220b9a91
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    glib-0.13.2.2-dee78e2394fbb4564d664049b5900c2d
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
